@@ -1,5 +1,6 @@
 import argparse
 from pathlib import Path
+import subprocess
 import mummify
 
 def cli():
@@ -14,18 +15,14 @@ def cli():
     parser.add_argument('function', choices=('history', 'switch'))
     parser.add_argument('id', nargs='?')
     args = parser.parse_args()
+    if not Path('.mummify').is_dir():
+        return 'mummify not initialized'
     if args.function == 'history':
-        if not Path('.mummify').is_dir():
-            print('mummify not initialized')
-            return
-        print(mummify.history())
-    elif args.function == 'switch' and args.id is not None:
-        if not Path('.mummify').is_dir():
-            print('mummify not initialized')
-            return
+        return mummify.history()
+    if args.function == 'switch' and args.id is not None:
         mummify.switch(args.id)
     else:
-        print('mummify id required')
+        return 'mummify id required'
 
 if __name__ == '__main__':
     cli()
